﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace OrderSystem
{
    public partial class Users : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                LoadUserDropDownList();
            }
        }

        private void LoadUserDropDownList()
        {
            using (OrderDBContainer db = new OrderDBContainer())
            {
                ddlUsers.DataSource = from u in db.UserAccounts
                                      orderby u.LastName
                                      select new { Name = u.LastName + ", " + u.FirstName, Id = u.Id };

                ddlUsers.DataTextField = "Name";
                ddlUsers.DataValueField = "Id";
                ddlUsers.DataBind();

                ddlUsers.Items.Insert(0, new ListItem("Create New User", ""));
            }
        }

        protected void btnSave_Click(object sender, EventArgs e)
        {
            using (OrderDBContainer db = new OrderDBContainer())
            {
                UserAccount userAccount = new UserAccount();
                userAccount.FirstName = txtFirstName.Text;
                userAccount.LastName = txtLastName.Text;
                userAccount.AuditFields.UpdateDate = DateTime.Now;

                if (ddlUsers.SelectedItem.Value == "")
                {
                    //Adding                    
                    userAccount.AuditFields.InsertDate = DateTime.Now;
                    db.UserAccounts.AddObject(userAccount);
                }
                else
                {
                    //Updating
                    userAccount.Id = Convert.ToInt32(ddlUsers.SelectedValue);
                    userAccount.AuditFields.InsertDate = Convert.ToDateTime(lblInserted.Text);

                    db.UserAccounts.Attach(userAccount);
                    db.ObjectStateManager.ChangeObjectState(userAccount, System.Data.EntityState.Modified);
                }

                db.SaveChanges();

                lblInserted.Text = userAccount.AuditFields.InsertDate.ToString();
                lblUpdated.Text = userAccount.AuditFields.UpdateDate.ToString();

                //Reload the drop down list
                LoadUserDropDownList();

                //Select the one the user just saved.
                ddlUsers.Items.FindByValue(userAccount.Id.ToString()).Selected = true;
            }
        }

        protected void ddlUsers_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (ddlUsers.SelectedValue == "")
            {
                txtFirstName.Text = "";
                txtLastName.Text = "";
                lblInserted.Text = "";
                lblUpdated.Text = "";
            }
            else
            {
                //Get the user from the DB
                using (OrderDBContainer db = new OrderDBContainer())
                {
                    int userAccountId = Convert.ToInt32(ddlUsers.SelectedValue);
                    List<UserAccount> userAccounts = (from u in db.UserAccounts
                                                      where u.Id == userAccountId
                                                      select u).ToList();

                    if (userAccounts.Count() > 0)
                    {
                        UserAccount userAccount = userAccounts[0];
                        txtFirstName.Text = userAccount.FirstName;
                        txtLastName.Text = userAccount.LastName;
                        lblInserted.Text = userAccount.AuditFields.InsertDate.ToString();
                        lblUpdated.Text = userAccount.AuditFields.UpdateDate.ToString();
                    }
                    else
                    {
                        //Error: didn't find user.
                        txtFirstName.Text = "";
                        txtLastName.Text = "";
                        lblInserted.Text = "";
                        lblUpdated.Text = "";
                    }
                }
            }
        }

        protected void btnDelete_Click(object sender, EventArgs e)
        {
            if (ddlUsers.SelectedItem.Value != "")
            {
                using (OrderDBContainer db = new OrderDBContainer())
                {
                    UserAccount userAccount = new UserAccount();
                    userAccount.Id = Convert.ToInt32(ddlUsers.SelectedValue);
                    db.UserAccounts.Attach(userAccount);
                    db.ObjectStateManager.ChangeObjectState(userAccount, System.Data.EntityState.Deleted);
                    db.SaveChanges();

                    LoadUserDropDownList();
                    txtFirstName.Text = "";
                    txtLastName.Text = "";
                    lblInserted.Text = "";
                    lblUpdated.Text = "";
                }
            }
        }
    }
}